@@ -1,12 +1,23 @@
 model.specials <- function(data,specials,allowInteractions=FALSE){
 
-  names(specials) <- specials
-  Terms <- attr(data,"terms")
-  spec <- lapply(specials,function(sp){
-    if (length(attr(Terms,"specials")[[sp]]))
-      untangle.specials(Terms,sp,1:10)
-    else NULL
-  })
+    names(specials) <- specials
+    Terms <- attr(data,"terms")
+    spec <- lapply(specials,function(sp){
+        if (length(attr(Terms,"specials")[[sp]])){
+            untangle <- function (tt, special, order = 1) {
+                spc <- attr(tt, "specials")[[special]]
+                if (length(spc) == 0) 
+                    return(list(vars = character(0), terms = numeric(0)))
+                facs <- attr(tt, "factor")
+                fname <- dimnames(facs)
+                ff <- apply(facs[spc, , drop = FALSE], 2, sum)
+                list(vars = (fname[[1]])[spc], terms = seq(ff)[ff & match(attr(tt, 
+                                                   "order"), order, nomatch = 0)])
+            }
+            untangle(Terms,sp,1:10)
+        }
+        else NULL
+    })
 
   # -------------------------check interactions-------------------------
   
